@@ -216,7 +216,6 @@ class Proxy(object):
             if Pyro4.config.METADATA:
                 warnings.warn("DOTTEDNAMES and METADATA are both enabled, DOTTEDNAMES doesn't really work in this situation", RuntimeWarning)
 
-
     def __del__(self):
         if hasattr(self, "_pyroConnection"):
             self._pyroRelease()
@@ -304,6 +303,10 @@ class Proxy(object):
     def __hash__(self):
         return hash(self._pyroUri)
 
+    def __dir__(self):
+        result = dir(self.__class__) + list(self.__dict__.keys())
+        return sorted(set(result) | self._pyroMethods | self._pyroAttrs)
+
     def _pyroRelease(self):
         """release the connection to the pyro daemon"""
         with self.__pyroConnLock:
@@ -482,7 +485,11 @@ class Proxy(object):
             raise
 
     def _pyroReconnect(self, tries=100000000):
-        """(re)connect the proxy to the daemon containing the pyro object which the proxy is for"""
+        """
+        (Re)connect the proxy to the daemon containing the pyro object which the proxy is for.
+        In contrast to the _pyroBind method, this one first releases the connection (if the proxy is still connected)
+        and retries making a new connection until it succeeds or the given amount of tries ran out.
+        """
         self._pyroRelease()
         while tries:
             try:
@@ -528,7 +535,7 @@ class _BatchedRemoteMethod(object):
 class _BatchProxyAdapter(object):
     """Helper class that lets you batch multiple method calls into one.
     It is constructed with a reference to the normal proxy that will
-    carry out the batched calls. Call methods on this object thatyou want to batch,
+    carry out the batched calls. Call methods on this object that you want to batch,
     and finally call the batch proxy itself. That call will return a generator
     for the results of every method call in the batch (in sequence)."""
 
@@ -656,16 +663,16 @@ def expose(method_or_class):
     """
     if inspect.isdatadescriptor(method_or_class):
         func = method_or_class.fget or method_or_class.fset or method_or_class.fdel
-        if func.__name__.startswith('_'):
+        if util.is_private_attribute(func.__name__):
             raise AttributeError("exposing private names (starting with _) is not allowed")
         func._pyroExposed = True
         return method_or_class
-    if method_or_class.__name__.startswith('_'):
+    if util.is_private_attribute(method_or_class.__name__):
         raise AttributeError("exposing private names (starting with _) is not allowed")
     if inspect.isclass(method_or_class):
         log.debug("exposing all members of %r", method_or_class)
         for name in method_or_class.__dict__:
-            if name.startswith('_'):
+            if util.is_private_attribute(name):
                 continue
             thing = getattr(method_or_class, name)
             if inspect.isfunction(thing):
@@ -673,11 +680,11 @@ def expose(method_or_class):
             elif inspect.ismethod(thing):
                 thing.__func__._pyroExposed = True
             elif inspect.isdatadescriptor(thing):
-                if thing.fset:
+                if getattr(thing, "fset", None):
                     thing.fset._pyroExposed = True
-                if thing.fget:
+                if getattr(thing, "fget", None):
                     thing.fget._pyroExposed = True
-                if thing.fdel:
+                if getattr(thing, "fdel", None):
                     thing.fdel._pyroExposed = True
     method_or_class._pyroExposed = True
     return method_or_class
